@@ -1,5 +1,7 @@
 from __future__ import annotations
 
+from typing import Literal
+
 from .calendar_helpers import parse_date, Date
 from .always_open import AlwaysOpenCalendar
 from .errors import CalendarNameCollision, CyclicCalendarAlias, InvalidCalendarName
@@ -202,7 +204,7 @@ class ExchangeCalendarDispatcher(object):
         name: str,
         start: Date | None = None,
         end: Date | None = None,
-        side: str | None = None,
+        side: Literal["left", "right", "both", "neither"] | None = None,
     ) -> ExchangeCalendar:
         """Get exchange calendar with a given name.
 
@@ -220,11 +222,14 @@ class ExchangeCalendarDispatcher(object):
 
         start : default: as default for calendar factory
             First calendar session will be `start`, if `start` is a
-            session, or first session after `start`.
+            session, or first session after `start`. Cannot be earlier than
+            any date returned by the respective calendar class method
+            `bound_min`.
 
         end : default: as default for calendar factory
             Last calendar session will be `end`, if `end` is a session, or
-            last session before `end`.
+            last session before `end`. Cannot be later than any date
+            returned by the respective calendar class method `bound_max`.
 
         side : default: as default for calendar factory
             Define which of session open/close and break start/end should
