@@ -1,4 +1,5 @@
 import pandas as pd
+from dateutil.easter import EASTER_ORTHODOX, easter
 from pandas.tseries.holiday import FR, DateOffset, Easter, Holiday
 from pandas.tseries.offsets import Day
 
@@ -432,3 +433,15 @@ eid_al_adha_first_day = pd.to_datetime(
         "2049-09-08",
     ]
 )
+
+
+def orthodox_easter(start_date="1980", end_date="2022"):
+    """
+    This function gives a DatetimeIndex of Orthodox Easter dates from start_date to end_date
+    """
+    return pd.to_datetime(
+        [
+            easter(year, method=EASTER_ORTHODOX)
+            for year in range(int(start_date), int(end_date))
+        ]
+    )
