@@ -40,10 +40,12 @@ EuropeanLabourDay = european_labour_day()
 # starting in 2015.
 WhitMonday2007AdHoc = Timestamp("2007-05-28")
 
-WhitMonday = whit_monday(start_date="2015-01-01")
+# Whit Monday and the Day of German Unity have been observed regularly, but in 2022 regular trading took place instead.
+#  It's unclear if it will be observed in 2023.
+WhitMondayUntil2022 = whit_monday(start_date="2015-01-01", end_date="2022-01-01")
 
-DayOfGermanUnity = Holiday(
-    "Day of German Unity", month=10, day=3, start_date="2014-01-01"
+DayOfGermanUnityUntil2022 = Holiday(
+    "Day of German Unity", month=10, day=3, start_date="2014-01-01", end_date="2022-01-01"
 )
 
 # Reformation Day was a German national holiday in 2017.
@@ -110,8 +112,8 @@ class XFRAExchangeCalendar(ExchangeCalendar):
                 GoodFriday,
                 EasterMonday,
                 EuropeanLabourDay,
-                WhitMonday,
-                DayOfGermanUnity,
+                WhitMondayUntil2022,
+                DayOfGermanUnityUntil2022,
                 ChristmasEve,
                 Christmas,
                 BoxingDay,
