@@ -2,7 +2,7 @@ from datetime import time
 from itertools import chain
 
 import pandas as pd
-from pytz import UTC, timezone
+import pytz
 
 from .exchange_calendar import HolidayCalendar, ExchangeCalendar
 from .xtks_holidays import (
@@ -52,12 +52,9 @@ class XTKSExchangeCalendar(ExchangeCalendar):
     Exchange calendar for the Tokyo Stock Exchange
 
     First session: 9:00am - 11:30am
-    Lunch
+    Lunch Break: 11:30am - 12:30pm
     Second session: 12:30pm - 3:00pm
 
-    NOTE: we are treating the two sessions per day as one session for now,
-    because we will not be handling minutely data in the immediate future.
-
     Regularly-Observed Holidays (see xtks_holidays.py for more info):
     - New Year's Holidays (Dec. 31 - Jan. 3)
     - Coming of Age Day (second Monday of January)
@@ -83,16 +80,17 @@ class XTKSExchangeCalendar(ExchangeCalendar):
 
     name = "XTKS"
 
-    tz = timezone("Asia/Tokyo")
+    tz = pytz.timezone("Asia/Tokyo")
 
     open_times = ((None, time(9)),)
-
+    break_start_times = ((None, time(11, 30)),)
+    break_end_times = ((None, time(12, 30)),)
     close_times = ((None, time(15)),)
 
-    @property
-    def bound_start(self) -> pd.Timestamp:
+    @classmethod
+    def bound_min(cls) -> pd.Timestamp:
         # not tracking holiday info farther back than 1997
-        return pd.Timestamp("1997-01-01", tz=UTC)
+        return pd.Timestamp("1997-01-01")
 
     @property
     def regular_holidays(self):
